@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,10 +18,18 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkgpdb.endpoint import endpoint_data
+
 class DescribeDBInstanceIPArrayListRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'gpdb', '2016-05-03', 'DescribeDBInstanceIPArrayList','gpdb')
+		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 
 	def get_DBInstanceId(self):
 		return self.get_query_params().get('DBInstanceId')
